/*******************************************************************************
* File Name: PWM_Window_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PWM_Window.h"

static PWM_Window_backupStruct PWM_Window_backup;


/*******************************************************************************
* Function Name: PWM_Window_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWM_Window_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void PWM_Window_SaveConfig(void) 
{

    #if(!PWM_Window_UsingFixedFunction)
        #if(!PWM_Window_PWMModeIsCenterAligned)
            PWM_Window_backup.PWMPeriod = PWM_Window_ReadPeriod();
        #endif /* (!PWM_Window_PWMModeIsCenterAligned) */
        PWM_Window_backup.PWMUdb = PWM_Window_ReadCounter();
        #if (PWM_Window_UseStatus)
            PWM_Window_backup.InterruptMaskValue = PWM_Window_STATUS_MASK;
        #endif /* (PWM_Window_UseStatus) */

        #if(PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_256_CLOCKS || \
            PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_2_4_CLOCKS)
            PWM_Window_backup.PWMdeadBandValue = PWM_Window_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(PWM_Window_KillModeMinTime)
             PWM_Window_backup.PWMKillCounterPeriod = PWM_Window_ReadKillTime();
        #endif /* (PWM_Window_KillModeMinTime) */

        #if(PWM_Window_UseControl)
            PWM_Window_backup.PWMControlRegister = PWM_Window_ReadControlRegister();
        #endif /* (PWM_Window_UseControl) */
    #endif  /* (!PWM_Window_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PWM_Window_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWM_Window_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void PWM_Window_RestoreConfig(void) 
{
        #if(!PWM_Window_UsingFixedFunction)
            #if(!PWM_Window_PWMModeIsCenterAligned)
                PWM_Window_WritePeriod(PWM_Window_backup.PWMPeriod);
            #endif /* (!PWM_Window_PWMModeIsCenterAligned) */

            PWM_Window_WriteCounter(PWM_Window_backup.PWMUdb);

            #if (PWM_Window_UseStatus)
                PWM_Window_STATUS_MASK = PWM_Window_backup.InterruptMaskValue;
            #endif /* (PWM_Window_UseStatus) */

            #if(PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_256_CLOCKS || \
                PWM_Window_DeadBandMode == PWM_Window__B_PWM__DBM_2_4_CLOCKS)
                PWM_Window_WriteDeadTime(PWM_Window_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(PWM_Window_KillModeMinTime)
                PWM_Window_WriteKillTime(PWM_Window_backup.PWMKillCounterPeriod);
            #endif /* (PWM_Window_KillModeMinTime) */

            #if(PWM_Window_UseControl)
                PWM_Window_WriteControlRegister(PWM_Window_backup.PWMControlRegister);
            #endif /* (PWM_Window_UseControl) */
        #endif  /* (!PWM_Window_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: PWM_Window_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWM_Window_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void PWM_Window_Sleep(void) 
{
    #if(PWM_Window_UseControl)
        if(PWM_Window_CTRL_ENABLE == (PWM_Window_CONTROL & PWM_Window_CTRL_ENABLE))
        {
            /*Component is enabled */
            PWM_Window_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            PWM_Window_backup.PWMEnableState = 0u;
        }
    #endif /* (PWM_Window_UseControl) */

    /* Stop component */
    PWM_Window_Stop();

    /* Save registers configuration */
    PWM_Window_SaveConfig();
}


/*******************************************************************************
* Function Name: PWM_Window_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWM_Window_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void PWM_Window_Wakeup(void) 
{
     /* Restore registers values */
    PWM_Window_RestoreConfig();

    if(PWM_Window_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        PWM_Window_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
